@@ -35,8 +35,7 @@ Usage::
 """
 from typing import Generic, Iterator, Mapping, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import (
     LocaleType,
@@ -81,7 +80,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListAccessPreviewFindingsPaginator(Boto3Paginator):
+class ListAccessPreviewFindingsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators/#listaccesspreviewfindingspaginator)
@@ -92,8 +91,8 @@ class ListAccessPreviewFindingsPaginator(Boto3Paginator):
         *,
         accessPreviewId: str,
         analyzerArn: str,
-        filter: Mapping[str, "CriterionTypeDef"] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        filter: Mapping[str, CriterionTypeDef] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAccessPreviewFindingsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviewFindings.paginate)
@@ -101,14 +100,14 @@ class ListAccessPreviewFindingsPaginator(Boto3Paginator):
         """
 
 
-class ListAccessPreviewsPaginator(Boto3Paginator):
+class ListAccessPreviewsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators/#listaccesspreviewspaginator)
     """
 
     def paginate(
-        self, *, analyzerArn: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, analyzerArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAccessPreviewsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAccessPreviews.paginate)
@@ -116,7 +115,7 @@ class ListAccessPreviewsPaginator(Boto3Paginator):
         """
 
 
-class ListAnalyzedResourcesPaginator(Boto3Paginator):
+class ListAnalyzedResourcesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators/#listanalyzedresourcespaginator)
@@ -127,7 +126,7 @@ class ListAnalyzedResourcesPaginator(Boto3Paginator):
         *,
         analyzerArn: str,
         resourceType: ResourceTypeType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAnalyzedResourcesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzedResources.paginate)
@@ -135,14 +134,14 @@ class ListAnalyzedResourcesPaginator(Boto3Paginator):
         """
 
 
-class ListAnalyzersPaginator(Boto3Paginator):
+class ListAnalyzersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators/#listanalyzerspaginator)
     """
 
     def paginate(
-        self, *, type: TypeType = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, type: TypeType = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAnalyzersResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListAnalyzers.paginate)
@@ -150,14 +149,14 @@ class ListAnalyzersPaginator(Boto3Paginator):
         """
 
 
-class ListArchiveRulesPaginator(Boto3Paginator):
+class ListArchiveRulesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators/#listarchiverulespaginator)
     """
 
     def paginate(
-        self, *, analyzerName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, analyzerName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListArchiveRulesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListArchiveRules.paginate)
@@ -165,7 +164,7 @@ class ListArchiveRulesPaginator(Boto3Paginator):
         """
 
 
-class ListFindingsPaginator(Boto3Paginator):
+class ListFindingsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators/#listfindingspaginator)
@@ -175,9 +174,9 @@ class ListFindingsPaginator(Boto3Paginator):
         self,
         *,
         analyzerArn: str,
-        filter: Mapping[str, "CriterionTypeDef"] = ...,
-        sort: "SortCriteriaTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        filter: Mapping[str, CriterionTypeDef] = ...,
+        sort: SortCriteriaTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListFindingsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListFindings.paginate)
@@ -185,14 +184,14 @@ class ListFindingsPaginator(Boto3Paginator):
         """
 
 
-class ListPolicyGenerationsPaginator(Boto3Paginator):
+class ListPolicyGenerationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators/#listpolicygenerationspaginator)
     """
 
     def paginate(
-        self, *, principalArn: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, principalArn: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListPolicyGenerationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ListPolicyGenerations.paginate)
@@ -200,7 +199,7 @@ class ListPolicyGenerationsPaginator(Boto3Paginator):
         """
 
 
-class ValidatePolicyPaginator(Boto3Paginator):
+class ValidatePolicyPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/paginators/#validatepolicypaginator)
@@ -213,7 +212,7 @@ class ValidatePolicyPaginator(Boto3Paginator):
         policyType: PolicyTypeType,
         locale: LocaleType = ...,
         validatePolicyResourceType: ValidatePolicyResourceTypeType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ValidatePolicyResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/accessanalyzer.html#AccessAnalyzer.Paginator.ValidatePolicy.paginate)
